.container {
    height: 100vh;
    width: 100vw;
    display: flex;
    flex-direction: column;
    justify-content: center;
    text-align: center;
    background-color: #222222;
    color: white;
}

.title {
    font-size: 4rem;
}

.desc {
    margin-top: 10px;
}

.counter-app {
    margin-top: 2rem;
    display: flex;
    flex-direction: column;
}

.counters {
    display: flex;
    justify-content: center;
    height: 50px;
    align-items: center;
}

.btn-counter {
    margin-left: 0.75rem;
    margin-right: 0.75rem;
}