* { 
	box-sizing: border-box;
    margin: 0;
}
html, body {
	min-height: 100%;
	background: #fff;
	color: #000;
}
	
body {
	font-size: 1.4rem;
	text-rendering: optimizeLegibility;
}
	
body, ul, ol, dl {
	margin: 0;
}